@@ -8,21 +8,21 @@ function(model) {
         x = list(as.matrix(as.data.frame(VarCorr(model)[[1]])))
       }
     names(x) <- sub("\\..*", "", names(temp))
-    
+
     lvar <- list()
     for (i in 1:length(ranef(model))){
       tmp <- list()
-      
+
       cond <- names(ranef(model))[i]
       for (j in 1:length(x)){
         if (names(x)[j] == cond) tmp[j] <- x[j]
       }
       tmp <- plyr::compact(tmp)
       
-      lvar[i] <- bdiag(tmp)
+      lvar[[i]] <- bdiag(tmp)
       names(lvar)[i] <- cond
-      
+
     }
     
   return(estimated_covariance_matrix = lvar)
-  }
\ No newline at end of file
+}
